package com.zhyc.module.base.mapper;

import java.util.List;

import com.zhyc.module.base.domain.BasSheepVariety;
import org.apache.ibatis.annotations.Mapper;

/**
 * 羊只品种Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Mapper
public interface BasSheepVarietyMapper 
{
    /**
     * 查询羊只品种
     * 
     * @param id 羊只品种主键
     * @return 羊只品种
     */
    public BasSheepVariety selectBasSheepVarietyById(Long id);

    /**
     * 查询羊只品种列表
     * 
     * @param basSheepVariety 羊只品种
     * @return 羊只品种集合
     */
    public List<BasSheepVariety> selectBasSheepVarietyList(BasSheepVariety basSheepVariety);

    /**
     * 新增羊只品种
     * 
     * @param basSheepVariety 羊只品种
     * @return 结果
     */
    public int insertBasSheepVariety(BasSheepVariety basSheepVariety);

    /**
     * 修改羊只品种
     * 
     * @param basSheepVariety 羊只品种
     * @return 结果
     */
    public int updateBasSheepVariety(BasSheepVariety basSheepVariety);

    /**
     * 删除羊只品种
     * 
     * @param id 羊只品种主键
     * @return 结果
     */
    public int deleteBasSheepVarietyById(Long id);

    /**
     * 批量删除羊只品种
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasSheepVarietyByIds(Long[] ids);


    /**
     * 根据品种名称查询品种 ID 用于导入羊只
     *
     * @param varietyName 品种名称
     * @return 品种 ID
     */
    Long selectIdByName(String varietyName);

    BasSheepVariety selectByVarietyName(String varietyName);
}
